@@ -64,6 +64,7 @@ new EventsRuleToStepFunction(scope: Construct, id: string, props: EventsRuleToSt
 |stateMachineProps|[`sfn.StateMachineProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-stepfunctions.StateMachineProps.html)|Optional user provided props to override the default props for sfn.StateMachine|
 |eventRuleProps|[`events.RuleProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.RuleProps.html)|User provided eventRuleProps to override the defaults|
 |createCloudWatchAlarms|`boolean`|Whether to create recommended CloudWatch alarms|
+|logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
 
 ## Pattern Properties
 
@@ -128,6 +129,7 @@ class EventsRuleToStepFunction(
         event_rule_props: aws_cdk.aws_events.RuleProps,
         state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
         """
         :param scope: - represents the scope for all the resources.
@@ -135,6 +137,7 @@ class EventsRuleToStepFunction(
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
         :param state_machine_props: User provided StateMachineProps to override the defaults. Default: - None
         :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
+        :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
 
         :access: public
         :since: 0.9.0
@@ -144,6 +147,7 @@ class EventsRuleToStepFunction(
             event_rule_props=event_rule_props,
             state_machine_props=state_machine_props,
             create_cloud_watch_alarms=create_cloud_watch_alarms,
+            log_group_props=log_group_props,
         )
 
         jsii.create(EventsRuleToStepFunction, self, [scope, id, props])
@@ -178,6 +182,7 @@ class EventsRuleToStepFunction(
         "event_rule_props": "eventRuleProps",
         "state_machine_props": "stateMachineProps",
         "create_cloud_watch_alarms": "createCloudWatchAlarms",
+        "log_group_props": "logGroupProps",
     },
 )
 class EventsRuleToStepFunctionProps:
@@ -187,11 +192,13 @@ class EventsRuleToStepFunctionProps:
         event_rule_props: aws_cdk.aws_events.RuleProps,
         state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
         """
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
         :param state_machine_props: User provided StateMachineProps to override the defaults. Default: - None
         :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
+        :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
 
         :summary: The properties for the EventsRuleToStepFunction Construct
         """
@@ -199,12 +206,16 @@ class EventsRuleToStepFunctionProps:
             event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
         if isinstance(state_machine_props, dict):
             state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
+        if isinstance(log_group_props, dict):
+            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         self._values: typing.Dict[str, typing.Any] = {
             "event_rule_props": event_rule_props,
             "state_machine_props": state_machine_props,
         }
         if create_cloud_watch_alarms is not None:
             self._values["create_cloud_watch_alarms"] = create_cloud_watch_alarms
+        if log_group_props is not None:
+            self._values["log_group_props"] = log_group_props
 
     @builtins.property
     def event_rule_props(self) -> aws_cdk.aws_events.RuleProps:
@@ -235,6 +246,15 @@ class EventsRuleToStepFunctionProps:
         result = self._values.get("create_cloud_watch_alarms")
         return result
 
+    @builtins.property
+    def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
+        """User provided props to override the default props for the CloudWatchLogs LogGroup.
+
+        :default: - Default props are used
+        """
+        result = self._values.get("log_group_props")
+        return result
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
